*********
Changelog
*********

0.2.0 (2024-03-29)
++++++++++++++++++

- Code quality improvements
- Fix missing assert in tests
- Drop support for python older than 3.8
- Adds read the docs configuration file
- Upgrade dependencies minimum required versions

0.1.2 (2020-06-09)
++++++++++++++++++

First release.